Ordinary Differential Equations
===============================

The behaviour of complex systems which evolve over time is often described via the use of ordinary differential equations.
ProbNum provides a set of methods to solve ordinary differential equations based on filtering approaches which quantify
the uncertainty introduced by discretization.

See the notebooks below to learn more about how to use ProbNum's functionality for ordinary differential equations.


.. nbgallery::
   :maxdepth: 2

   odes/adaptive_steps_odefilter
   odes/uncertainties_odefilters
   odes/odesolvers_from_scratch

----

You can also interactively try out the |Tutorials| directly in the browser or
by downloading the notebooks from the
`GitHub repository <https://github.com/probabilistic-numerics/probnum/tree/master/docs/source/tutorials>`_.

.. |Tutorials| image:: https://img.shields.io/badge/Tutorials-Jupyter-579ACA.svg?&logo=Jupyter&logoColor=white
    :target: https://mybinder.org/v2/gh/probabilistic-numerics/probnum/master?filepath=docs%2Fsource%2Ftutorials
    :alt: ProbNum's Tutorials
